# CONTENTS OF THIS FILE
---
 * Introduction
 * Installation
 * Requirements
 * Recommended modules
 * Configuration
 * Cookies
 * Customize
 * Troubleshooting
 * FAQ
 * Maintainers

## INTRODUCTION
---
The Klaro consent manager module implements the [Klaro! consent manager utility](https://klaro.kiprotect.com) for Drupal 8.

### What is it good for?
The primary use case for this module is to:

- **Provide** a configurable consent/cookie manager for the site visitor, to give (or decline) consent to predefined "apps".
- **Satisfy** the [EU cookie guidelines](https://edpb.europa.eu/sites/edpb/files/files/file1/edpb_guidelines_202005_consent_en.pdf) (PDF)
- **Manipulate** scripts and other resources added by Drupal and/or its modules to adhere to the users' preference.

### Goals
- Fully customizable, managable and translatable consents (*apps*).
- Fully customizable, managable and translatable *purposes*.
- Fully customizable and translatable texts of the consent manager.

## INSTALLATION
---
The installation of this module is like other Drupal modules.

1. Place the klaro Drupal module in the `modules` directory of your Drupal installation.
2. Place the [`kiprotect/klaro`](https://github.com/kiprotect/klaro/releases/latest) javascript library in your site's `libraries` folder.
3. Enable the 'Klaro!' module in 'Extend': `/admin/modules`.
4. Set up user permissions: `/admin/people/permissions#module-klaro`.

You can alternatively use composer for steps 1 & 2, but must add the javascript library manually to your site's `composer.json`, e.g.

```json
"repositories": [
	{
		"type": "package",
		"package": {
		    "name": "kiprotect/klaro",
		    "type": "drupal-library",
		    "version": "0.5.32",
		    "dist": {
		        "url": "https://github.com/kiprotect/klaro/archive/v0.5.32.zip",
		        "type": "zip"
		    }
		}
	}
]
```
You can then use `composer require drupal/klaro` and `composer require kiprotect/klaro` to install the module and library.

## REQUIREMENTS
---
This module only requires the [`kiprotect/klaro`](https://github.com/kiprotect/klaro)
javascript library. No other Drupal modules are required.

## RECOMMENDED MODULES
---

* [Configuration Translation](https://www.drupal.org/docs/8/core/modules/config-translation) for multilingual sites.

## CONFIGURATION
---
The module comes with some pre-defined *purposes*, such as "CMS" for Drupal-related cookies or "Analytics". These are used to group individual cookies, trackers etc. It also ships with some *app* settings, e.g. for analytics provided by Matomo, based on your site's installed modules.

### Backend / UI

* Configure Klaro! general behavior at `/admin/config/user-interface/klaro`.
* Create a new klaro app: `/admin/config/user-interface/klaro/apps` or edit an existing app: `/admin/config/user-interface/klaro/apps/klaro`.
* Add a new klaro purpose: `/admin/config/user-interface/klaro/purposes` or edit an existing purpose: `/admin/config/user-interface/klaro/purposes/cms`.
* Specify your privacy policy url and customize modal texts: `/admin/config/user-interface/klaro/texts`.

## COOKIES
---
To let klaro delete cookies there are two places to provide information about them.

1. `/admin/config/user-interface/klaro/apps/{klaro_app}`
   Inside the `Advanced` section you can provide specific cookie information about `name` (regex), `path` and `domain`
2. `/admin/config/user-interface/klaro`
   Inside the `Advanced` section you will find the `Matching cookie domains` textarea. Sometimes scripts may set cookies with dynamic cookie domains. You can add different domains here so that klaro will try to delete all cookies definied in your apps additionally with this cookie domains. So you don't need to add 30 cookie information inside your app just because a script adds several cookies just with 10 differen cookie domains.

## Customize
---
### Open the Klaro! consent manager modal

* By default if the user gave a consent and saves, the manager modal will disappear.
* If you like to provide a link or button to the user to make the manager appear again, you can use the `rel`-attribute of any clickable element to let Klaro! open the consent manager.
* Just use the `rel`-Value `open-consent-manager`.
* If there is / are already any `rel`-value(s) just extend the value e.g. `<a href="/privacy-policy" rel="nofollow open-consent-manager noindex">`.

### Inline-Scripts

If you have inline scripts in your content authored via CKEditor or any other RTE like this:
* `<script src="https://myscriptremotesource">...</script>`

and you want that Klaro! takes controll of the execution of this, you first need to decide, which consent (app) will execute this script if the visitor will give his consent.

E.g. if your klaro app ID is `foo`, then this markup of the script above should be changed to this:
* `<script type="text/plain" data-type="text/javascript" data-name="foo" data-src="https://myscriptremotesource">..."></script>`

If there are image pixels that tracks the visitor like this:
* `<img src="htps://mypixeltracker.com" width="1" height="1" />`

just change it to this:
* `<img data-src="htps://mypixeltracker.com" data-name="foo" width="1" height="1" />`

## TROUBLESHOOTING
---
- If the script- / resource **element attibutes** won't appear like the
  `type="text/plain"` then maybe some other module or the theme is
  preprocessing the script tag by stripping out this attribute.
- Issue tracker: https://www.drupal.org/project/issues/klaro?version=any_8.x-

## FAQ
---
Q: Why must I install the library locally, when I could use the remote url
  instead?
A: Because klaro is all about privacy, and we don't want to pass information
  about your user's browsing behavior to GitHub. Furthermore, it's a security
  feature that you can be a 100% certain which code runs on your site.

Q: I don't like the styling, what can I do?
A: You can override files used in Drupal libraries using your theme's
  `mytheme.info.yml`, by defining a `libraries-override` for `klaro/library`
  to remove `css/klaro.min.css`. See https://www.drupal.org/node/2497313 for
  additional information.

## Maintainers
---
   * Jan Kellermann (jan kellermann) - https://www.drupal.org/u/jan-kellermann
   * Christian Kipke (ckidow) - https://www.drupal.org/u/ckidow
